export default {
    "index": 14,
    "lineNumber": 2,
    "column": 1,
    "message": "Unexpected token *"
};